Stan Math Library: stan/math/rev/core/operator_not_equal.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
operator_not_equal.hpp File Reference
`#include <stan/math/rev/core/var.hpp>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
bool | stan::math::operator!= (const var &a, const var &b)
| Inequality operator comparing two variables' values (C++). More...
bool | stan::math::operator!= (const var &a, const double b)
| Inequality operator comparing a variable's value and a double (C++). More...
bool | stan::math::operator!= (const double a, const var &b)
| Inequality operator comparing a double and a variable's value (C++). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.